@@ -40,7 +40,6 @@ class ProductController
         add_filter('woocommerce_pagination_args', [$this, 'customWoocommercePagination']);
         add_filter('woocommerce_product_single_add_to_cart_text', [$this, 'customAddToCartText']);
         add_filter('woocommerce_account_menu_items', [$this, 'updateAccountMenu'], 999);
-        add_filter('woocommerce_account_menu_items', [$this, 'updateAccountMenu'], 999);
         add_filter('woocommerce_sale_flash', [$this, 'removeSaleBadge']);
         add_filter('woocommerce_get_stock_html', [$this, 'hideInStockMessage'], 10, 3);
     }
@@ -89,7 +88,7 @@ class ProductController
     {
         $args['prev_text'] = 'Previous';
         $args['next_text'] = 'Next';
-        $args['mid_size'] = 0;
+        $args['mid_size'] = 1;
         $args['end_size'] = 1;
         $args['show_all'] = false;
         return $args;
@@ -166,7 +165,12 @@ class ProductController
                 $query->set('meta_query', $metaQuery);
             }
 
-            if (isset($_GET['sort-by']) && $_GET['sort-by'] !== '') {
+            if(!isset($_GET['sort-by'])) {
+                $query->set('orderby', 'meta_value_num');
+                $query->set('meta_key', '_price');
+                $query->set('order', 'DESC');
+            }
+            else if (isset($_GET['sort-by']) && $_GET['sort-by'] !== '') {
                 $sortType = $_GET['sort-by'];
                 if ($sortType == 'low-to-high') {
                     $query->set('orderby', 'meta_value_num');
@@ -176,6 +180,9 @@ class ProductController
                     $query->set('orderby', 'meta_value_num');
                     $query->set('meta_key', '_price');
                     $query->set('order', 'DESC');
+                } else if($sortType == 'name'){
+                    $query->set('orderby', 'title');
+                    $query->set('order', 'ASC');
                 }
             }
         }
@@ -229,14 +236,15 @@ class ProductController
         $saleClass = $product->get_sale_price() ? 'sale-active' : 'sale-inactive';
         $displayPrice = wc_get_price_to_display( $product, ['price' => $product->get_regular_price()]);
         $salePrice = wc_get_price_to_display( $product, ['price' => $product->get_sale_price()]);
+        $vatMessage = get_option('woocommerce_price_display_suffix') ? ' <span class="vat-suffix">' . get_option('woocommerce_price_display_suffix') . '</span>' : "";
         ?>
 
         <div class="price">
             <div class="inner-price rrp <?= $saleClass; ?>">
-                <span class="amount"><?= get_woocommerce_currency_symbol() . number_format($displayPrice, 2) . '</span> <span class="price-suffix">RRP</span>'; ?>
+                <span class="amount"><?= get_woocommerce_currency_symbol() . number_format($displayPrice, 2) . '</span> <span class="price-suffix">RRP</span>' . $vatMessage; ?>
             </div>
             <?php if ($product->get_sale_price()) { ?>
-                <div class="inner-price sale"><?= get_woocommerce_currency_symbol() . number_format($salePrice,2) . ' <span class="price-suffix">Our Price</span>'; ?></div>
+                <div class="inner-price sale"><?= get_woocommerce_currency_symbol() . number_format($salePrice,2) . ' <span class="price-suffix">Our Price</span>' . $vatMessage; ?></div>
             <?php } ?>
         </div>
     <?php }
@@ -336,12 +344,9 @@ class ProductController
 
     public static function ibcosSync()
     {
-        ini_set('max_execution_time', 300);
-        set_time_limit(300);
         $new_items = 0;
         $old_items = 0;
 
-
         $args = array('limit' => -1);
         $products = wc_get_products($args);
         $out_of_stock_staus = 'outofstock';
